@@ -284,9 +284,8 @@ impl FromStr for PrivateKey {
 /// This derives the master key from seed bytes, the actual usage is typically
 /// for Cosmos key_import support, where we import a seed phrase.
 fn master_key_from_seed(seed_bytes: &[u8]) -> ([u8; 32], [u8; 32]) {
-    use hmac::crypto_mac::Mac;
-    use hmac::crypto_mac::NewMac;
     use hmac::Hmac;
+    use hmac::Mac;
     type HmacSha512 = Hmac<Sha512>;
 
     let mut hasher = HmacSha512::new_from_slice(b"Bitcoin seed").unwrap();
@@ -312,9 +311,8 @@ fn get_child_key(
     i: u32,
     hardened: bool,
 ) -> ([u8; 32], [u8; 32]) {
-    use hmac::crypto_mac::Mac;
-    use hmac::crypto_mac::NewMac;
     use hmac::Hmac;
+    use hmac::Mac;
     type HmacSha512 = Hmac<Sha512>;
 
     let i = if hardened { 2u32.pow(31) + i } else { i };
